//$Id: rcp-saver.h,v 1.6 2004/06/12 12:14:32 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2004 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_IO_RCP_SAVER_H
#define GUIKACHU_IO_RCP_SAVER_H

#include "io.h"

namespace Guikachu
{
    namespace IO
    {
	class RCPSaver: public Saver
	{
	public:
	    IOResult save (ResourceManager *manager, const Glib::ustring &uri);
	};
	
    }
}

#endif /* !GUIKACHU_IO_RCP_SAVER_H */
